# geodemo_lee


[![image](https://img.shields.io/pypi/v/geodemo_lee.svg)](https://pypi.python.org/pypi/geodemo_lee)
[![image](https://img.shields.io/conda/vn/conda-forge/geodemo_lee.svg)](https://anaconda.org/conda-forge/geodemo_lee)


**A Python package for geodemo**


-   Free software: MIT license
-   Documentation: https://LyMot.github.io/geodemo_lee
    

## Features

-   TODO
